@@ -3,7 +3,7 @@
   extprot:  compact, efficient, extensible binary serialization format
 
 This is a python implementation of the 'extprot' serialization scheme, the
-details of which are descripted in detail at:
+details of which are described at:
 
     http://eigenclass.org/R2/writings/extprot-extensible-protocols-intro
 
@@ -44,7 +44,7 @@ Extprot compares favourably to related serialization technologies:
 
    * powerful type system;  strongly-typed tuples and lists, tagged disjoint
                             unions, parametric polymorphism.
-   * self-delimitng data;   all serialized messages indicate their length,
+   * self-delimiting data;  all serialized messages indicate their length,
                             allowing easy streaming and skipping of messages.
    * self-describing data;  the 'skeleton' of a message can be reconstructed
                             without having the protocol definition.
@@ -72,7 +72,7 @@ through extprot/compiler.py like so:
 
 __ver_major__ = 0
 __ver_minor__ = 2
-__ver_patch__ = 1
+__ver_patch__ = 2
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,
                               __ver_patch__,__ver_sub__)
